diff mbox series

sound/pci/bt87x: Replaces 'blacklist' with 'no_audio_list'

Message ID 20200716064102.632618-1-paul@mawsonlakes.org (mailing list archive)
State New, archived
Headers show
Series sound/pci/bt87x: Replaces 'blacklist' with 'no_audio_list' | expand

Commit Message

Paul Schulz July 16, 2020, 6:41 a.m. UTC
This patch removes 'blacklist' and replaces it with
the more descriptive 'no_audio_list'

This is a functionally trivial patch and has no other effect.

Signed-off-by: Paul Schulz <paul@mawsonlakes.org>
---
 sound/pci/bt87x.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

Comments

Takashi Iwai July 16, 2020, 7:46 a.m. UTC | #1
On Thu, 16 Jul 2020 08:41:02 +0200,
Paul Schulz wrote:
> 
> This patch removes 'blacklist' and replaces it with
> the more descriptive 'no_audio_list'
> 
> This is a functionally trivial patch and has no other effect.
> 
> Signed-off-by: Paul Schulz <paul@mawsonlakes.org>

The blacklist/whitelist words are already covered in sound git tree.


thanks,

Takashi
diff mbox series

Patch

diff --git a/sound/pci/bt87x.c b/sound/pci/bt87x.c
index 6567504665b9..b74b55bdb146 100644
--- a/sound/pci/bt87x.c
+++ b/sound/pci/bt87x.c
@@ -801,7 +801,7 @@  MODULE_DEVICE_TABLE(pci, snd_bt87x_ids);
  * (DVB cards use the audio function to transfer MPEG data) */
 static struct {
 	unsigned short subvendor, subdevice;
-} blacklist[] = {
+} no_audio_list[] = {
 	{0x0071, 0x0101}, /* Nebula Electronics DigiTV */
 	{0x11bd, 0x001c}, /* Pinnacle PCTV Sat */
 	{0x11bd, 0x0026}, /* Pinnacle PCTV SAT CI */
@@ -817,7 +817,7 @@  static struct {
 
 static struct pci_driver driver;
 
 /* return the id of the card, or a negative value if it's blacklisted */
 static int snd_bt87x_detect_card(struct pci_dev *pci)
 {
 	int i;
@@ -827,9 +827,9 @@  static int snd_bt87x_detect_card(struct pci_dev *pci)
 	if (supported && supported->driver_data > 0)
 		return supported->driver_data;
 
-	for (i = 0; i < ARRAY_SIZE(blacklist); ++i)
-		if (blacklist[i].subvendor == pci->subsystem_vendor &&
-		    blacklist[i].subdevice == pci->subsystem_device) {
+	for (i = 0; i < ARRAY_SIZE(no_audio_list); ++i)
+		if (no_audio_list[i].subvendor == pci->subsystem_vendor &&
+		    no_audio_list[i].subdevice == pci->subsystem_device) {
 			dev_dbg(&pci->dev,
 				"card %#04x-%#04x:%#04x has no audio\n",
 				    pci->device, pci->subsystem_vendor, pci->subsystem_device);
@@ -817,7 +817,7 @@  static struct {
 static struct pci_driver driver;
 
-/* return the id of the card, or a negative value if it's blacklisted */
+/* return the id of the card, or a negative value if it's in the no_audio_list */
 static int snd_bt87x_detect_card(struct pci_dev *pci)
 {